@@ -1,3 +1,6 @@
+{-# LANGUAGE CPP #-}
+{-# LANGUAGE GeneralizedNewtypeDeriving #-}
+
 {-|
 This module re-exports the types from @System.Posix.Types@ on all platforms.
 
@@ -5,15 +8,17 @@ On Windows 'UserID', 'GroupID' and 'LinkCount' are missing, so they are
 redefined by this module.
 -}
 module System.PosixCompat.Types (
-    module System.Posix.Types,
-#ifdef MISSING_POSIX_TYPES
-    UserID, GroupID, LinkCount
+      module System.Posix.Types
+#ifdef mingw32_HOST_OS
+    , UserID
+    , GroupID
+    , LinkCount
 #endif
-  ) where
+    ) where
 
 import System.Posix.Types
 
-#ifdef MISSING_POSIX_TYPES
+#ifdef mingw32_HOST_OS
 
 import Data.Word (Word32)
 
@@ -36,4 +41,3 @@ instance Read LinkCount where readsPrec i s = [ (LinkCount x, s')
                                               | (x,s') <- readsPrec i s]
 
 #endif
-
